import request from "@/utils/request";
import { it } from "element-plus/es/locales.mjs";

// 查询参数列表
export function listTools(query) {
  return request({
    url: "/tool/basis/list",
    method: "get",
    params: query,
  });
}
// 查询大类,二类树状信息
export function listToolTypes(query) {
  return request({
    url: "/tool/basis/basisTree",
    method: "get",
    params: query,
  });
}

// 根据 id 获取工具详情
export function getToolDetailById(id){
  return request({
    url: `/tool/basis/${id}`,
    method: "get",
  });
}

// 获取工具类型字典
export function queryToolDict(level,parentId) {
  return new Promise((resolve, reject) => {
    request({
      url: "/tool/basis/list",
      method: "get",
      params: {
        level,
        parentId,
      },
    })
      .then((res) => {
        const result = res.rows.map((item) => ({
          id: item.id,
          label: item.toolName,
        }));
        resolve(result);
      })
      .catch((err) => reject(err));
  });
}

// 添加工具、分类基本信息
export function toolAdd(data) {
  return request({
    url: "/tool/basis/add",
    method: "post",
    data,
  });
}

// 修改工具、分类基本信息
export function toolUpdate(data) {
  return request({
    url: "/tool/basis/updateBasis",
    method: "post",
    data,
  });
}
// 删除工具、分类基本信息
export function toolDelete(id) {
  return request({
    url: `/tool/basis/delete/${id}`,
    method: "delete",
  });
}

// 根据基础信息id查询附件信息
export function listFileByBasisId(query) {
  return request({
    url: "/basis/detail/list",
    method: "get",
    params:query,
  });
}

// 给对应基础信息添加附件
export function addFileByBasisId(data) {
  return request({
    url: "/basis/detail/add",
    method: "post",
    data,
  });
}

// 对应基础信息附件进行更新
export function updateFileByBasisId(data) {
  return request({
    url: "/basis/detail/update",
    method: "post",
    data,
  });
}
// 对应基础信息附件进行更新(根据id单个更新)
export function updateFileById(data) {
  return request({
    url: "/basis/detail/updateMaterial",
    method: "post",
    data,
  });
}

// 对应基础信息附件进行删除
export function deleteFileByBasisId(ids) {
  return request({
    url: `/basis/detail/delete/${ids}`,
    method: "delete",
  });
}




