import {
  toolAdd,
  toolUpdate,
  updateFileByBasisId,
} from "@/api/bussiness";
// 提交表单的 hooks
const useSubmitForm = (getList) => {
  const { proxy } = getCurrentInstance();
  // 弹窗是否打开
  const open = ref(false);
  // 弹窗的标题
  const title = ref("");
  // 表单的 loading 状态
  const formLoading = ref(false);
  const data = reactive({
    // 表单数据
    form: {
      parentId: undefined,
      toolName: undefined,
      describe: undefined,
      // 手册附件
      manualFileList: [],
      // 资料附件
      resourceFileList: [],
    },
    // 表单规则
    rules: {
      toolName: [
        { required: true, message: "分类名称不能为空", trigger: "blur" },
      ],
    },
  });

  const { form, rules } = toRefs(data);

  // 表单分类选项改变
  const handleFormTypeChange = (val) => {
    if (!val) {
      form.value.manualFileList = [];
      form.value.resourceFileList = [];
    }
  };
  // 表单重置 
  const reset = () => {
    form.value = {
      parentId: undefined,
      toolName: undefined,
      describe: undefined,
      manualFileList: [],
      resourceFileList: [],
    };
    proxy.resetForm("toolTypesRef");
  };

  // 更新关联的文件
  const fileUpdate = (basisId) => {
    const manualFileList = form.value.manualFileList.map((item) => ({
      id: item.id,
      basisId: basisId,
      fileName: item.name,
      filePath: item.url,
      informationType: "sc",
    }));
    const resourceFileList = form.value.resourceFileList.map((item) => ({
      id: item.id,
      basisId: basisId,
      fileName: item.name,
      filePath: item.url,
      informationType: "zl",
    }));
    const allFiles = manualFileList.concat(resourceFileList);
    return updateFileByBasisId({
      basisId: basisId,
      fileList: allFiles,
    });
  };

  // 更新工具分类
  const updateToolType = () => {
    const baseParams = {
      ...form.value,
      parentId: form.value.parentId || "0",
      level: form.value.parentId ? "2" : "1",
    };
    // const allFiles = form.value.manualFileList.concat(form.value.resourceFileList)
    const promiseApis = [
      toolUpdate(baseParams),
      fileUpdate(form.value.id),
    ];
    Promise.all(promiseApis).then((res) => {
      proxy.$modal.msgSuccess("修改成功");
      open.value = false;
      getList();
    });
  };

  // 添加工具分类
  const addToolType = () => {
    const params = {
      ...form.value,
      parentId: form.value.parentId || "0",
      level: form.value.parentId ? "2" : "1",
    };
    toolAdd(params).then((res) => {
      fileUpdate(res.data).then(() => {
        proxy.$modal.msgSuccess("新增成功");
        open.value = false;
        getList();
      });
    });
  };

  // 提交按钮
  const submitForm = () => {
    proxy.$refs["toolTypesRef"].validate((valid) => {
      if (valid) {
        if (form.value.id != undefined) {
          updateToolType();
        } else {
          addToolType();
        }
      }
    });
  };
  // 取消按钮
  const cancel = () => {
    open.value = false;
    reset();
  };
  return {
    title,
    open,
    form,
    rules,
    formLoading,
    handleFormTypeChange,
    reset,
    submitForm,
    cancel,
  };
};

export default useSubmitForm;
