import {
  toolAdd,
  toolUpdate,
  queryToolDict,
  updateFileByBasisId,
} from "@/api/bussiness";
// 提交表单的 hooks
const useSubmitForm = (getTableData) => {
  const { proxy } = getCurrentInstance();
  const formLoading = ref(false);
  // 提交表单的数据
  const form = ref({
    toolName: "",
    aliasName: "",
    levelOneId: "",
    levelTwoId: "",
    describe: "",
    specifications: "",
    example: "",
    toolNum: 0,
    manualFileList: [],
    resourceFileList: [],
    imageList: [],
  });
  // 校验数量
  const checkNums = (rule, value, callback) => {
    if(value <= 0){
      callback(new Error('数量必须大于0'))
    }
    callback()
  }
  // 表单的规则
  const rules = ref({
    toolName: [
      { required: true, message: "分类名称不能为空", trigger: "blur" },
    ],
    specifications: [
      { required: true, message: "规格标准说明不能为空", trigger: "blur" },
    ],
    example: [{ required: true, message: "举例不能为空", trigger: "blur" }],
    levelOneId: [
      { required: true, message: "所属一级分类不能为空", trigger: "change" },
    ],
    levelTwoId: [
      { required: true, message: "所属二级分类不能为空", trigger: "change" },
    ],
    toolNum:[
      { required: true, message: "数量不能为空", trigger: "blur" },
      { validator: checkNums, trigger: 'change' },
    ]
  });
  // 弹窗是否打开
  const open = ref(false);
  // 弹窗标题
  const title = ref("");
  // 提交表单的二类下拉列表数据
  const submitFormLevelTwoDict = ref([]);
  // 更新关联的文件
  const fileUpdate = (basisId) => {
    // 手册文件
    const manualFileList = form.value.manualFileList.map((item) => ({
      id: item.id,
      basisId: basisId,
      fileName: item.name,
      filePath: item.url,
      informationType: "sc",
    }));
    // 资料文件
    const resourceFileList = form.value.resourceFileList.map((item) => ({
      id: item.id,
      basisId: basisId,
      fileName: item.name,
      filePath: item.url,
      informationType: "zl",
    }));
    // 示意图文件
    const imageList = form.value.imageList.map((item) => ({
      id: item.id,
      basisId: basisId,
      fileName: item.name,
      filePath: item.url,
      informationType: "syt",
    }));
    const allFiles = [...manualFileList, ...resourceFileList, ...imageList];
    return updateFileByBasisId({
      basisId: basisId,
      fileList: allFiles,
    });
  };
  // 更新工具
  const updateTool = () => {
    const baseParams = {
      ...form.value,
      parentId: form.value.levelTwoId,
      level: "3",
    };
    // const allFiles = form.value.manualFileList.concat(form.value.resourceFileList)
    const promiseApis = [
      toolUpdate(baseParams),
      fileUpdate(form.value.id),
    ];
    Promise.all(promiseApis).then((res) => {
      proxy.$modal.msgSuccess("修改成功");
      open.value = false;
      getTableData();
    });
  };

  // 添加工具
  const addTool = () => {
    const params = {
      ...form.value,
      parentId: form.value.levelTwoId,
      level: "3",
    };
    toolAdd(params).then((res) => {
      fileUpdate(res.data).then(() => {
        proxy.$modal.msgSuccess("新增成功");
        open.value = false;
        getTableData();
      });
    });
  };
  // 提交按钮 
  const submitForm = () => {
    proxy.$refs["toolRef"].validate((valid) => {
      if (valid) {
        if (form.value.id != undefined) {
          updateTool();
        } else {
          addTool();
        }
      }
    });
  };
  // 取消按钮
  const cancel = () => {
    open.value = false;
    reset();
  };
  // 表单重置 
  const reset = () => {
    form.value = {
      toolName: "",
      aliasName: "",
      levelOneId: "",
      levelTwoId: "",
      describe: "",
      toolNum: 0,
      manualFileList: [],
      resourceFileList: [],
      imageList: [],
    };
    proxy.resetForm("toolRef");
  };
  // 获取二级分类字典
  const updateTypeTwoDict = (parentId) => {
    queryToolDict("2", parentId).then((data) => {
      submitFormLevelTwoDict.value = data || [];
    });
  };
  // 一级分类改变时，更新二级分类列表，并清空一级分类
  const handleChangeSubmitFormLevelType = (val) => {
    form.value.levelTwoId = "";
    updateTypeTwoDict(val);
  };
  return {
    form,
    rules,
    open,
    title,
    formLoading,
    submitFormLevelTwoDict,
    submitForm,
    cancel,
    reset,
    handleChangeSubmitFormLevelType,
  };
};

export default useSubmitForm;
