import { useRoute } from "vue-router";
import { getToolDetailById } from "@/api/bussiness";
// 初始化 hooks
const useInit = () => {
  const route = useRoute();
  const toolId = ref();
  const toolInfo = ref({});

  // 根据类型的id获取类型的名称
  const getTypeName = (typeId)=>{
    return getToolDetailById(typeId).then((res)=>{
      const data = res.data || {}
      return data.toolName || ""
    })
  }
  // 根据id获取大类和二级类别的中文
  const getTypeByAncestors = (ancestors)=>{
    if(!ancestors) return Promise.resolve()
    const idList = ancestors.split(',')
    const promiseList = [getTypeName(idList[1]),getTypeName(idList[2])]
    return Promise.all(promiseList).then(([type1,type2])=>{
      toolInfo.value = {
        ...toolInfo.value,
        levelOneTypeName: type1,
        levelTwoTypeName: type2,
      }
      return toolInfo.value
    })
  }
  // 初始化函数，获取route中的工具id并开始初始化页面数据
  const init = () => {
    const query = route.query;
    toolId.value = query.toolId;
    // 获取工具信息
    return getToolDetailById(query.toolId).then((res)=>{
      toolInfo.value = res.data || {}
      // 根据父级类别获取大类和二类的数据
      return getTypeByAncestors( res.data.ancestors || '')
    })
  };

  return {
    toolId,
    toolInfo,
    init,
  };
};

export default useInit;
